#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021-01-12 17:38
# @Site    :
# @File    : raspberryScan.py
# @Software: PyCharm
"""获取本地ip"""
import socket
import threading
from XZGUtil.logger import conlog

# 创建互斥锁
lock = threading.Lock()



class MyThread(threading.Thread):  # MyThread类继承threading.Thread类
    def __init__(self, func, args1=None, args2=None):
        threading.Thread.__init__(self)
        self.func = func
        self.args1 = args1
        self.args2 = args2

    def run(self):  # t.start()语句调用run方法
        self.result = self.func(self.args1, self.args2)

    def getResult(self):  # getResult方法可获得func函数return的结果
        threading.Thread.join(self)
        return self.result

def get_host_ip():
    """
    查询本机ip地址
    :return:
    """
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(('8.8.8.8', 80))
        ip = s.getsockname()[0]
    finally:
        s.close()
    return ip

# 定义查询路由函数
def search_routers(pt = "22"):
    # 设置需要扫描的端口号列表
    port_list = [pt]
    routers = []
    # 创建接收路由列表
    # 获取本地ip地址列表
    local_ips = socket.gethostbyname_ex(socket.gethostname())[2]
    # conlog(local_ips)
    # 存放线程列表池
    all_threads = []
    # 循环本地网卡IP列表
    for ip in local_ips:
        for i in range(1, 255):
            # 把网卡IP"."进行分割,生成每一个可用地址的列表
            array = ip.split('.')
            # 获取分割后的第四位数字，生成该网段所有可用IP地址
            array[3] = str(i)
            # 把分割后的每一可用地址列表，用"."连接起来，生成新的ip
            new_ip = '.'.join(array)
            # conlog(new_ip)
            # 遍历需要扫描的端口号列表
            for port in port_list:
                dst_port = int(port)
                # 循环创建线程去链接该地址
                t = MyThread(check_ip, new_ip, dst_port)
                t.start()
                # 把新建的线程放到线程池
                all_threads.append(t)
    # 循环阻塞主线程，等待每一字子线程执行完，程序再退出
    for t in all_threads:
        t.join()
    for value in all_threads:
        if value.getResult():
            routers += value.getResult()
    return routers


# 创建访问IP列表方法
def check_ip(new_ip, port):
    routers = []
    # 创建TCP套接字，链接新的ip列表
    scan_link = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    # 设置链接超时时间
    scan_link.settimeout(2)
    # 链接地址(通过指定我们 构造的主机地址，和扫描指定端口)
    result = scan_link.connect_ex((new_ip, port))
    #
    scan_link.close()
    # conlog(result)
    # 判断链接结果
    if result == 0:
        # 加锁
        lock.acquire()
        conlog(new_ip, '\t\t端口号%s开放' % port)
        routers.append((new_ip, port))
        # 释放锁
        lock.release()
    return routers


def serch_smp_ip():
    """查询树莓派IP"""
    l1 = search_routers()
    conlog("l1", l1)
    input("请关闭树莓派后，回车")
    l2 = search_routers()
    conlog("l2", l2)
    for i in l1:
        if i not in l2:
            conlog("树莓派ip为：", i)


if __name__ == '__main__':
    # 启动扫描程序
    serch_smp_ip()



#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time    : 2022-06-16 10:07
# @Site    :
# @File    : dealFile.py
# @Software: PyCharm
"""
读取，写入表格文件
"""
import csv
import os
import traceback

import xlrd
import openpyxl as op
from openpyxl.utils.exceptions import InvalidFileException
from xlrd import XLRDError


def clean_directory(path):
    """清空文件夹"""
    if not os.path.exists(path):
        return
    for i in os.listdir(path):
        path_file = os.path.join(path, i)
        if os.path.isfile(path_file):
            os.remove(path_file)
        else:
            for f in os.listdir(path_file):
                path_file2 = os.path.join(path_file, f)
            if os.path.isfile(path_file2):
                os.remove(path_file2)

def create_excel_xlsx(path, sheet_name):
    """创建excel"""
    workbook = op.Workbook()
    sheet = workbook.active
    sheet.title = sheet_name
    workbook.save(path)

def write_excel_xlsx_append(path,name, value,sheet_name = 'Sheet1', truncate_sheet=False):
    """
    :param path: ./demo/sycm.xlsx
    :param value: [[],[]]
    :param truncate_sheet:truncate_sheet为True，覆盖原表中的数据
    :return:
    """
    # 如果不存在就创建该excel
    if not os.path.exists(f"{path}"):
        os.makedirs(path)
    if not os.path.exists(f"{path}/{name}", ):
        create_excel_xlsx(f"{path}/{name}", sheet_name)
    data = op.load_workbook(f"{path}/{name}", )
    # 取第一张表
    sheetnames = data.sheetnames
    sheet = data[sheetnames[0]]
    sheet = data.active
    if(truncate_sheet): #truncate_sheet为True，覆盖原表中的数据
        startrows = 0
    else:
        # print(sheet.title)  # 输出表名
        startrows = sheet.max_row  # 获得行数
    index = len(value)
    for i in range(0, index):
        for j in range(0, len(value[i])):
            sheet.cell(row=startrows + i + 1, column=j + 1, value=str(value[i][j]))
    data.save(f"{path}/{name}",)
    print("xlsx格式表格追加写入数据成功！")

def read_excel_xlsx(path, sheet_name):
    workbook = op.load_workbook(path)
    sheet = workbook[sheet_name]
    for row in sheet.rows:
        for cell in row:
            print(cell.value, "\t", end="")
        print()


def read_excel(path: str, sheet: str = None, encoding="utf-8", del_file=False):
    """
    读取文件
    :param path:  文件路径
    :param sheet:  有sheet页的需要指定sheet名字,不指定默认第一个sheet
    :param encoding:  编码格式
    :param del_file:  读取完成后是否删除文件，默认不删除
    :return:
    """
    if path[-4:] == ".csv":
        with open(path, encoding=encoding) as f:
            reader = csv.reader(f)
            lr = tuple([tuple(item) for item in reader])
    elif path[-5:] in ['.xlsx', '.xlsm', '.xltx', '.xltm']:
            workbook = op.load_workbook(path)
            if not sheet:
                sheet = workbook.sheetnames[0]
            sheet = workbook[sheet]  # 获取表单
            max_row = sheet.max_row  # 获取最大行数
            max_column = sheet.max_column  # 获取最大列数
            lr = tuple([tuple([sheet.cell(row=row, column=column).value for column in range(1, max_column+1)]) for row in range(1, max_row+1)])
    elif path[-4:] == ".xls":
            workbook = xlrd.open_workbook(path)  # 打开工作簿
            if not sheet:
                sheet = workbook.sheet_names()[0]
            sheet = workbook.sheet_by_name(sheet_name=sheet)  # 获取表单
            max_row = sheet.nrows  # 获取最大行
            max_column = sheet.ncols  # 获取最大列数
            lr = tuple([tuple([sheet.cell_value(rowx=row, colx=column) for column in range(0, max_column)]) for row in range(0, max_row)])
    else:
        traceback.print_exc()
        assert False, "当前文件格式不支持，支持格式：.xlsx,.xlsm,.xltx,.xltm .xls .csv"
    if del_file:
        os.remove(path)
    return lr



if __name__ == '__main__':
    print(read_excel(r"E:\chenfan_work\gitlib\工具类\util\xzg_util\XZGUtil\270977983_创意_上新快_2022-11-10.xls"))
